{"00000:1": "

    {% extends '_base.html' -%}\n{% block mainpage -%}\n<div id="featured-content-wrapper">\n    <div class="12u" id="feature-content">\n        <div class="5grid-layout">\n            <div class="row">\n                {{ content.one }}\n            </div>\n        </div>\n    </div>\n</div>\n<div id="page-wrapper">\n    <div class="divider"></div>\n    <div class="12u">\n        <div class="5grid-layout" id="page">\n            <div class="row">\n                <div class="7u">\n                    {{ content.two }}\n\n                </div>\n                <div class="1u">&nbsp;</div>\n                <div class="2u" id="sidebar1">\n                    {{ content.three }}\n                </div>\n                <div class="2u">\n                    {{ content.four }}\n                </div>\n            </div>\n        </div>\n    </div>\n</div>\n{% endblock -%}\n

\n"}